__version__ = '0.3.0'

__author__ = 'Joost VanDorp'

__email__ = 'joostvandorp@gmail.com'

__url__ = 'https://github.com/vandorjw/django-assessment'

__license__ = 'MIT'

VERSION = __version__  # synonym
